"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.command = void 0;
const clc = require("colorette");
const command_1 = require("../command");
const fsi = require("../firestore/api");
const logger_1 = require("../logger");
const requirePermissions_1 = require("../requirePermissions");
const types_1 = require("../emulator/types");
const commandUtils_1 = require("../emulator/commandUtils");
const pretty_print_1 = require("../firestore/pretty-print");
exports.command = new command_1.Command("firestore:databases:restore")
    .description("Restore a Firestore database in your Firebase project.")
    .option("-d, --database <databaseID>", "ID of the database to restore into")
    .option("-b, --backup <backup>", "Backup from which to restore")
    .before(requirePermissions_1.requirePermissions, ["datastore.backups.restoreDatabase"])
    .before(commandUtils_1.warnEmulatorNotSupported, types_1.Emulators.FIRESTORE)
    .action(async (options) => {
    const api = new fsi.FirestoreApi();
    const printer = new pretty_print_1.PrettyPrint();
    if (!options.database) {
        logger_1.logger.error("Missing required flag --database. See firebase firestore:databases:restore --help for more info");
        return;
    }
    const databaseId = options.database;
    if (!options.backup) {
        logger_1.logger.error("Missing required flag --backup. See firebase firestore:databases:restore --help for more info");
        return;
    }
    const backupName = options.backup;
    const databaseResp = await api.restoreDatabase(options.project, databaseId, backupName);
    if (options.json) {
        logger_1.logger.info(JSON.stringify(databaseResp, undefined, 2));
    }
    else {
        logger_1.logger.info(clc.bold(`Successfully initiated restore of ${printer.prettyDatabaseString(databaseResp)}`));
        logger_1.logger.info("Please be sure to configure Firebase rules in your Firebase config file for\n" +
            "the new database. By default, created databases will have closed rules that\n" +
            "block any incoming third-party traffic.");
        logger_1.logger.info(`Once the restore is complete, your database may be viewed at ${printer.firebaseConsoleDatabaseUrl(options.project, databaseId)}`);
    }
    return databaseResp;
});
